@@ -1,12 +1,11 @@
-// Copyright (c) Microsoft Corporation. All rights reserved.
-// Licensed under the MIT License. See the LICENSE file in builder/azure for license information.
-
 package arm
 
 import (
-	"github.com/mitchellh/packer/builder/azure/common/constants"
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
+	"context"
+
+	"github.com/hashicorp/packer/builder/azure/common/constants"
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 type StepSetCertificate struct {
@@ -25,13 +24,12 @@ func NewStepSetCertificate(config *Config, ui packer.Ui) *StepSetCertificate {
 	return step
 }
 
-func (s *StepSetCertificate) Run(state multistep.StateBag) multistep.StepAction {
+func (s *StepSetCertificate) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	s.say("Setting the certificate's URL ...")
 
 	var winRMCertificateUrl = state.Get(constants.ArmCertificateUrl).(string)
 	s.config.tmpWinRMCertificateUrl = winRMCertificateUrl
 
-	state.Put(constants.ArmTemplateParameters, s.config.toTemplateParameters())
 	return multistep.ActionContinue
 }
 
