@@ -1,17 +1,19 @@
 package docker
 
 import (
+	"context"
 	"fmt"
 	"os"
+	"path/filepath"
 
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 // StepExport exports the container to a flat tar file.
 type StepExport struct{}
 
-func (s *StepExport) Run(state multistep.StateBag) multistep.StepAction {
+func (s *StepExport) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	config := state.Get("config").(*Config)
 
 	driver := state.Get("driver").(Driver)
@@ -26,6 +28,13 @@ func (s *StepExport) Run(state multistep.StateBag) multistep.StepAction {
 		return multistep.ActionHalt
 	}
 
+	// Make the directory we're exporting to if it doesn't exist
+	exportDir := filepath.Dir(config.ExportPath)
+	if err := os.MkdirAll(exportDir, 0755); err != nil {
+		state.Put("error", err)
+		return multistep.ActionHalt
+	}
+
 	// Open the file that we're going to write to
 	f, err := os.Create(config.ExportPath)
 	if err != nil {
