@@ -1,11 +1,13 @@
 package docker
 
 import (
+	"context"
 	"fmt"
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
-	"io/ioutil"
 	"os"
+	"path/filepath"
+
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 // StepTempDir creates a temporary directory that we use in order to
@@ -14,18 +16,33 @@ type StepTempDir struct {
 	tempDir string
 }
 
-func (s *StepTempDir) Run(state multistep.StateBag) multistep.StepAction {
+// ConfigTmpDir returns the configuration tmp directory for Docker
+func ConfigTmpDir() (string, error) {
+	if tmpdir := os.Getenv("PACKER_TMP_DIR"); tmpdir != "" {
+		return filepath.Abs(tmpdir)
+	}
+	configdir, err := packer.ConfigDir()
+	if err != nil {
+		return "", err
+	}
+	td := filepath.Join(configdir, "tmp")
+	_, err = os.Stat(td)
+	if os.IsNotExist(err) {
+		if err = os.MkdirAll(td, 0755); err != nil {
+			return "", err
+		}
+	} else if err != nil {
+		return "", err
+	}
+	return td, nil
+}
+
+func (s *StepTempDir) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	ui := state.Get("ui").(packer.Ui)
 
 	ui.Say("Creating a temporary directory for sharing data...")
 
-	var err error
-	var tempdir string
-
-	configTmpDir, err := packer.ConfigTmpDir()
-	if err == nil {
-		tempdir, err = ioutil.TempDir(configTmpDir, "packer-docker")
-	}
+	tempdir, err := ConfigTmpDir()
 	if err != nil {
 		err := fmt.Errorf("Error making temp dir: %s", err)
 		state.Put("error", err)
