@@ -1,24 +1,25 @@
 package openstack
 
 import (
+	"context"
 	"fmt"
 	"time"
 
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
-	"github.com/rackspace/gophercloud/openstack/compute/v2/servers"
+	"github.com/gophercloud/gophercloud/openstack/compute/v2/servers"
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 type StepWaitForRackConnect struct {
 	Wait bool
 }
 
-func (s *StepWaitForRackConnect) Run(state multistep.StateBag) multistep.StepAction {
+func (s *StepWaitForRackConnect) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	if !s.Wait {
 		return multistep.ActionContinue
 	}
 
-	config := state.Get("config").(Config)
+	config := state.Get("config").(*Config)
 	server := state.Get("server").(*servers.Server)
 	ui := state.Get("ui").(packer.Ui)
 
