@@ -1,13 +1,15 @@
 package common
 
 import (
+	"context"
 	"fmt"
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
+
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
-// This step removes all empty blocks from expanding Parallels virtual disks
-// and reduces the result disk size
+// StepCompactDisk is a step that removes all empty blocks from expanding
+// Parallels virtual disks and reduces the result disk size
 //
 // Uses:
 //   driver Driver
@@ -20,7 +22,8 @@ type StepCompactDisk struct {
 	Skip bool
 }
 
-func (s *StepCompactDisk) Run(state multistep.StateBag) multistep.StepAction {
+// Run runs the compaction of the virtual disk attached to the VM.
+func (s *StepCompactDisk) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	driver := state.Get("driver").(Driver)
 	vmName := state.Get("vmName").(string)
 	ui := state.Get("ui").(packer.Ui)
@@ -33,7 +36,7 @@ func (s *StepCompactDisk) Run(state multistep.StateBag) multistep.StepAction {
 	ui.Say("Compacting the disk image")
 	diskPath, err := driver.DiskPath(vmName)
 	if err != nil {
-		err := fmt.Errorf("Error detecting virtual disk path: %s", err)
+		err = fmt.Errorf("Error detecting virtual disk path: %s", err)
 		state.Put("error", err)
 		ui.Error(err.Error())
 		return multistep.ActionHalt
@@ -48,4 +51,5 @@ func (s *StepCompactDisk) Run(state multistep.StateBag) multistep.StepAction {
 	return multistep.ActionContinue
 }
 
+// Cleanup does nothing.
 func (*StepCompactDisk) Cleanup(multistep.StateBag) {}
