@@ -1,18 +1,19 @@
 package qemu
 
 import (
+	"context"
 	"fmt"
 	"path/filepath"
 
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 // This step copies the virtual disk that will be used as the
 // hard drive for the virtual machine.
 type stepCopyDisk struct{}
 
-func (s *stepCopyDisk) Run(state multistep.StateBag) multistep.StepAction {
+func (s *stepCopyDisk) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	config := state.Get("config").(*Config)
 	driver := state.Get("driver").(Driver)
 	isoPath := state.Get("iso_path").(string)
@@ -22,13 +23,12 @@ func (s *stepCopyDisk) Run(state multistep.StateBag) multistep.StepAction {
 
 	command := []string{
 		"convert",
-		"-f", config.Format,
 		"-O", config.Format,
 		isoPath,
 		path,
 	}
 
-	if config.DiskImage == false {
+	if !config.DiskImage || config.UseBackingFile {
 		return multistep.ActionContinue
 	}
 
