@@ -1,10 +1,11 @@
 package common
 
 import (
+	"context"
 	"fmt"
 	"os"
 
-	"github.com/mitchellh/multistep"
+	"github.com/hashicorp/packer/helper/multistep"
 )
 
 type StepPrepareTools struct {
@@ -12,7 +13,7 @@ type StepPrepareTools struct {
 	ToolsUploadFlavor string
 }
 
-func (c *StepPrepareTools) Run(state multistep.StateBag) multistep.StepAction {
+func (c *StepPrepareTools) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	driver := state.Get("driver").(Driver)
 
 	if c.RemoteType == "esx5" {
