@@ -1,15 +1,11 @@
 package main
 
 import (
-	"os"
-	"os/signal"
-
+	"github.com/hashicorp/packer/command"
 	"github.com/mitchellh/cli"
-	"github.com/mitchellh/packer/command"
-	"github.com/mitchellh/packer/version"
 )
 
-// Commands is the mapping of all the available Terraform commands.
+// Commands is the mapping of all the available Packer commands.
 var Commands map[string]cli.CommandFactory
 
 // CommandMeta is the Meta to use for the commands. This must be written
@@ -39,12 +35,6 @@ func init() {
 			}, nil
 		},
 
-		"push": func() (cli.Command, error) {
-			return &command.PushCommand{
-				Meta: *CommandMeta,
-			}, nil
-		},
-
 		"validate": func() (cli.Command, error) {
 			return &command.ValidateCommand{
 				Meta: *CommandMeta,
@@ -53,11 +43,8 @@ func init() {
 
 		"version": func() (cli.Command, error) {
 			return &command.VersionCommand{
-				Meta:              *CommandMeta,
-				Revision:          version.GitCommit,
-				Version:           version.Version,
-				VersionPrerelease: version.VersionPrerelease,
-				CheckFunc:         commandVersionCheck,
+				Meta:      *CommandMeta,
+				CheckFunc: commandVersionCheck,
 			}, nil
 		},
 
@@ -68,20 +55,3 @@ func init() {
 		},
 	}
 }
-
-// makeShutdownCh creates an interrupt listener and returns a channel.
-// A message will be sent on the channel for every interrupt received.
-func makeShutdownCh() <-chan struct{} {
-	resultCh := make(chan struct{})
-
-	signalCh := make(chan os.Signal, 4)
-	signal.Notify(signalCh, os.Interrupt)
-	go func() {
-		for {
-			<-signalCh
-			resultCh <- struct{}{}
-		}
-	}()
-
-	return resultCh
-}
