@@ -13,10 +13,10 @@ import (
 	"path/filepath"
 	"strconv"
 	"strings"
-	"sync"
 	"time"
 
-	"github.com/mitchellh/packer/packer"
+	"github.com/hashicorp/packer/packer"
+	"github.com/hashicorp/packer/packer/tmp"
 	"github.com/pkg/sftp"
 	"golang.org/x/crypto/ssh"
 	"golang.org/x/crypto/ssh/agent"
@@ -47,8 +47,8 @@ type Config struct {
 	// Pty, if true, will request a pty from the remote end.
 	Pty bool
 
-	// DisableAgent, if true, will not forward the SSH agent.
-	DisableAgent bool
+	// DisableAgentForwarding, if true, will not forward the SSH agent.
+	DisableAgentForwarding bool
 
 	// HandshakeTimeout limits the amount of time we'll wait to handshake before
 	// saying the connection failed.
@@ -56,6 +56,13 @@ type Config struct {
 
 	// UseSftp, if true, sftp will be used instead of scp for file transfers
 	UseSftp bool
+
+	// KeepAliveInterval sets how often we send a channel request to the
+	// server. A value < 0 disables.
+	KeepAliveInterval time.Duration
+
+	// Timeout is how long to wait for a read or write to succeed.
+	Timeout time.Duration
 }
 
 // Creates a new packer.Communicator implementation over SSH. This takes
@@ -99,16 +106,25 @@ func (c *comm) Start(cmd *packer.RemoteCmd) (err error) {
 		}
 	}
 
-	log.Printf("starting remote command: %s", cmd.Command)
+	log.Printf("[DEBUG] starting remote command: %s", cmd.Command)
 	err = session.Start(cmd.Command + "\n")
 	if err != nil {
 		return
 	}
 
-	// A channel to keep track of our done state
-	doneCh := make(chan struct{})
-	sessionLock := new(sync.Mutex)
-	timedOut := false
+	go func() {
+		if c.config.KeepAliveInterval <= 0 {
+			return
+		}
+		c := time.NewTicker(c.config.KeepAliveInterval)
+		defer c.Stop()
+		for range c.C {
+			_, err := session.SendRequest("keepalive@packer.io", true, nil)
+			if err != nil {
+				return
+			}
+		}
+	}()
 
 	// Start a goroutine to wait for the session to end and set the
 	// exit boolean and status.
@@ -118,25 +134,19 @@ func (c *comm) Start(cmd *packer.RemoteCmd) (err error) {
 		err := session.Wait()
 		exitStatus := 0
 		if err != nil {
-			exitErr, ok := err.(*ssh.ExitError)
-			if ok {
-				exitStatus = exitErr.ExitStatus()
+			switch err.(type) {
+			case *ssh.ExitError:
+				exitStatus = err.(*ssh.ExitError).ExitStatus()
+				log.Printf("[ERROR] Remote command exited with '%d': %s", exitStatus, cmd.Command)
+			case *ssh.ExitMissingError:
+				log.Printf("[ERROR] Remote command exited without exit status or exit signal.")
+				exitStatus = packer.CmdDisconnect
+			default:
+				log.Printf("[ERROR] Error occurred waiting for ssh session: %s", err.Error())
 			}
 		}
-
-		sessionLock.Lock()
-		defer sessionLock.Unlock()
-
-		if timedOut {
-			// We timed out, so set the exit status to -1
-			exitStatus = -1
-		}
-
-		log.Printf("remote command exited with '%d': %s", exitStatus, cmd.Command)
 		cmd.SetExited(exitStatus)
-		close(doneCh)
 	}()
-
 	return
 }
 
@@ -149,7 +159,7 @@ func (c *comm) Upload(path string, input io.Reader, fi *os.FileInfo) error {
 }
 
 func (c *comm) UploadDir(dst string, src string, excl []string) error {
-	log.Printf("Upload dir '%s' to '%s'", src, dst)
+	log.Printf("[DEBUG] Upload dir '%s' to '%s'", src, dst)
 	if c.config.UseSftp {
 		return c.sftpUploadDirSession(dst, src, excl)
 	} else {
@@ -158,8 +168,9 @@ func (c *comm) UploadDir(dst string, src string, excl []string) error {
 }
 
 func (c *comm) DownloadDir(src string, dst string, excl []string) error {
-	log.Printf("Download dir '%s' to '%s'", src, dst)
+	log.Printf("[DEBUG] Download dir '%s' to '%s'", src, dst)
 	scpFunc := func(w io.Writer, stdoutR *bufio.Reader) error {
+		dirStack := []string{dst}
 		for {
 			fmt.Fprint(w, "\x00")
 
@@ -175,18 +186,25 @@ func (c *comm) DownloadDir(src string, dst string, excl []string) error {
 
 			switch fi[0] {
 			case '\x01', '\x02':
-				return fmt.Errorf("%s", fi[1:len(fi)])
+				return fmt.Errorf("%s", fi[1:])
 			case 'C', 'D':
 				break
+			case 'E':
+				dirStack = dirStack[:len(dirStack)-1]
+				if len(dirStack) == 0 {
+					fmt.Fprint(w, "\x00")
+					return nil
+				}
+				continue
 			default:
 				return fmt.Errorf("unexpected server response (%x)", fi[0])
 			}
 
-			var mode string
+			var mode int64
 			var size int64
 			var name string
-			log.Printf("Download dir str:%s", fi)
-			n, err := fmt.Sscanf(fi, "%6s %d %s", &mode, &size, &name)
+			log.Printf("[DEBUG] Download dir str:%s", fi)
+			n, err := fmt.Sscanf(fi[1:], "%o %d %s", &mode, &size, &name)
 			if err != nil || n != 3 {
 				return fmt.Errorf("can't parse server response (%s)", fi)
 			}
@@ -194,18 +212,20 @@ func (c *comm) DownloadDir(src string, dst string, excl []string) error {
 				return fmt.Errorf("negative file size")
 			}
 
-			log.Printf("Download dir mode:%s size:%d name:%s", mode, size, name)
+			log.Printf("[DEBUG] Download dir mode:%0o size:%d name:%s", mode, size, name)
+
+			dst = filepath.Join(dirStack...)
 			switch fi[0] {
 			case 'D':
-				err = os.MkdirAll(filepath.Join(dst, name), os.FileMode(0755))
+				err = os.MkdirAll(filepath.Join(dst, name), os.FileMode(mode))
 				if err != nil {
 					return err
 				}
-				fmt.Fprint(w, "\x00")
-				return nil
+				dirStack = append(dirStack, name)
+				continue
 			case 'C':
 				fmt.Fprint(w, "\x00")
-				err = scpDownloadFile(filepath.Join(dst, name), stdoutR, size, os.FileMode(0644))
+				err = scpDownloadFile(filepath.Join(dst, name), stdoutR, size, os.FileMode(mode))
 				if err != nil {
 					return err
 				}
@@ -227,7 +247,7 @@ func (c *comm) Download(path string, output io.Writer) error {
 }
 
 func (c *comm) newSession() (session *ssh.Session, err error) {
-	log.Println("opening new ssh session")
+	log.Println("[DEBUG] Opening new ssh session")
 	if c.client == nil {
 		err = errors.New("client not available")
 	} else {
@@ -235,12 +255,16 @@ func (c *comm) newSession() (session *ssh.Session, err error) {
 	}
 
 	if err != nil {
-		log.Printf("ssh session open error: '%s', attempting reconnect", err)
+		log.Printf("[ERROR] ssh session open error: '%s', attempting reconnect", err)
 		if err := c.reconnect(); err != nil {
 			return nil, err
 		}
 
-		return c.client.NewSession()
+		if c.client == nil {
+			return nil, errors.New("client not available")
+		} else {
+			return c.client.NewSession()
+		}
 	}
 
 	return session, nil
@@ -248,6 +272,7 @@ func (c *comm) newSession() (session *ssh.Session, err error) {
 
 func (c *comm) reconnect() (err error) {
 	if c.conn != nil {
+		// Ignore errors here because we don't care if it fails
 		c.conn.Close()
 	}
 
@@ -255,7 +280,7 @@ func (c *comm) reconnect() (err error) {
 	c.conn = nil
 	c.client = nil
 
-	log.Printf("reconnecting to TCP connection for SSH")
+	log.Printf("[DEBUG] reconnecting to TCP connection for SSH")
 	c.conn, err = c.config.Connection()
 	if err != nil {
 		// Explicitly set this to the REAL nil. Connection() can return
@@ -266,11 +291,15 @@ func (c *comm) reconnect() (err error) {
 		// http://golang.org/doc/faq#nil_error
 		c.conn = nil
 
-		log.Printf("reconnection error: %s", err)
+		log.Printf("[ERROR] reconnection error: %s", err)
 		return
 	}
 
-	log.Printf("handshaking with SSH")
+	if c.config.Timeout > 0 {
+		c.conn = &timeoutConn{c.conn, c.config.Timeout, c.config.Timeout}
+	}
+
+	log.Printf("[DEBUG] handshaking with SSH")
 
 	// Default timeout to 1 minute if it wasn't specified (zero value). For
 	// when you need to handshake from low orbit.
@@ -307,10 +336,9 @@ func (c *comm) reconnect() (err error) {
 	}
 
 	if err != nil {
-		log.Printf("handshake error: %s", err)
 		return
 	}
-	log.Printf("handshake complete!")
+	log.Printf("[DEBUG] handshake complete!")
 	if sshConn != nil {
 		c.client = ssh.NewClient(sshConn, sshChan, req)
 	}
@@ -324,7 +352,7 @@ func (c *comm) connectToAgent() {
 		return
 	}
 
-	if c.config.DisableAgent {
+	if c.config.DisableAgentForwarding {
 		log.Printf("[INFO] SSH agent forwarding is disabled.")
 		return
 	}
@@ -374,15 +402,14 @@ func (c *comm) connectToAgent() {
 
 func (c *comm) sftpUploadSession(path string, input io.Reader, fi *os.FileInfo) error {
 	sftpFunc := func(client *sftp.Client) error {
-		return sftpUploadFile(path, input, client, fi)
+		return c.sftpUploadFile(path, input, client, fi)
 	}
 
 	return c.sftpSession(sftpFunc)
 }
 
-func sftpUploadFile(path string, input io.Reader, client *sftp.Client, fi *os.FileInfo) error {
+func (c *comm) sftpUploadFile(path string, input io.Reader, client *sftp.Client, fi *os.FileInfo) error {
 	log.Printf("[DEBUG] sftp: uploading %s", path)
-
 	f, err := client.Create(path)
 	if err != nil {
 		return err
@@ -408,7 +435,7 @@ func (c *comm) sftpUploadDirSession(dst string, src string, excl []string) error
 	sftpFunc := func(client *sftp.Client) error {
 		rootDst := dst
 		if src[len(src)-1] != '/' {
-			log.Printf("No trailing slash, creating the source directory name")
+			log.Printf("[DEBUG] No trailing slash, creating the source directory name")
 			rootDst = filepath.Join(dst, filepath.Base(src))
 		}
 		walkFunc := func(path string, info os.FileInfo, err error) error {
@@ -433,7 +460,7 @@ func (c *comm) sftpUploadDirSession(dst string, src string, excl []string) error
 				return nil
 			}
 
-			return sftpVisitFile(finalDst, path, info, client)
+			return c.sftpVisitFile(finalDst, path, info, client)
 		}
 
 		return filepath.Walk(src, walkFunc)
@@ -442,7 +469,7 @@ func (c *comm) sftpUploadDirSession(dst string, src string, excl []string) error
 	return c.sftpSession(sftpFunc)
 }
 
-func sftpMkdir(path string, client *sftp.Client, fi os.FileInfo) error {
+func (c *comm) sftpMkdir(path string, client *sftp.Client, fi os.FileInfo) error {
 	log.Printf("[DEBUG] sftp: creating dir %s", path)
 
 	if err := client.Mkdir(path); err != nil {
@@ -460,16 +487,16 @@ func sftpMkdir(path string, client *sftp.Client, fi os.FileInfo) error {
 	return nil
 }
 
-func sftpVisitFile(dst string, src string, fi os.FileInfo, client *sftp.Client) error {
+func (c *comm) sftpVisitFile(dst string, src string, fi os.FileInfo, client *sftp.Client) error {
 	if !fi.IsDir() {
 		f, err := os.Open(src)
 		if err != nil {
 			return err
 		}
 		defer f.Close()
-		return sftpUploadFile(dst, f, client, &fi)
+		return c.sftpUploadFile(dst, f, client, &fi)
 	} else {
-		err := sftpMkdir(dst, client, fi)
+		err := c.sftpMkdir(dst, client, fi)
 		return err
 	}
 }
@@ -495,7 +522,7 @@ func (c *comm) sftpDownloadSession(path string, output io.Writer) error {
 func (c *comm) sftpSession(f func(*sftp.Client) error) error {
 	client, err := c.newSftpClient()
 	if err != nil {
-		return err
+		return fmt.Errorf("sftpSession error: %s", err.Error())
 	}
 	defer client.Close()
 
@@ -521,7 +548,15 @@ func (c *comm) newSftpClient() (*sftp.Client, error) {
 		return nil, err
 	}
 
-	return sftp.NewClientPipe(pr, pw)
+	// Capture stdout so we can return errors to the user
+	var stdout bytes.Buffer
+	tee := io.TeeReader(pr, &stdout)
+	client, err := sftp.NewClientPipe(tee, pw)
+	if err != nil && stdout.Len() > 0 {
+		log.Printf("[ERROR] Upload failed: %s", stdout.Bytes())
+	}
+
+	return client, err
 }
 
 func (c *comm) scpUploadSession(path string, input io.Reader, fi *os.FileInfo) error {
@@ -530,11 +565,14 @@ func (c *comm) scpUploadSession(path string, input io.Reader, fi *os.FileInfo) e
 	target_dir := filepath.Dir(path)
 	target_file := filepath.Base(path)
 
-	// On windows, filepath.Dir uses backslash seperators (ie. "\tmp").
+	// On windows, filepath.Dir uses backslash separators (ie. "\tmp").
 	// This does not work when the target host is unix.  Switch to forward slash
 	// which works for unix and windows
 	target_dir = filepath.ToSlash(target_dir)
 
+	// Escape spaces in remote directory
+	target_dir = strings.Replace(target_dir, " ", "\\ ", -1)
+
 	scpFunc := func(w io.Writer, stdoutR *bufio.Reader) error {
 		return scpUploadFile(target_file, input, w, stdoutR, fi)
 	}
@@ -560,7 +598,7 @@ func (c *comm) scpUploadDirSession(dst string, src string, excl []string) error
 		}
 
 		if src[len(src)-1] != '/' {
-			log.Printf("No trailing slash, creating the source directory name")
+			log.Printf("[DEBUG] No trailing slash, creating the source directory name")
 			fi, err := os.Stat(src)
 			if err != nil {
 				return err
@@ -591,7 +629,7 @@ func (c *comm) scpDownloadSession(path string, output io.Writer) error {
 
 		switch fi[0] {
 		case '\x01', '\x02':
-			return fmt.Errorf("%s", fi[1:len(fi)])
+			return fmt.Errorf("%s", fi[1:])
 		case 'C':
 		case 'D':
 			return fmt.Errorf("remote file is directory")
@@ -618,14 +656,10 @@ func (c *comm) scpDownloadSession(path string, output io.Writer) error {
 
 		fmt.Fprint(w, "\x00")
 
-		if err := checkSCPStatus(stdoutR); err != nil {
-			return err
-		}
-
-		return nil
+		return checkSCPStatus(stdoutR)
 	}
 
-	if strings.Index(path, " ") == -1 {
+	if !strings.Contains(path, " ") {
 		return c.scpSession("scp -vf "+path, scpFunc)
 	}
 	return c.scpSession("scp -vf "+strconv.Quote(path), scpFunc)
@@ -665,7 +699,7 @@ func (c *comm) scpSession(scpCommand string, f func(io.Writer, *bufio.Reader) er
 
 	// Start the sink mode on the other side
 	// TODO(mitchellh): There are probably issues with shell escaping the path
-	log.Println("Starting remote scp process: ", scpCommand)
+	log.Println("[DEBUG] Starting remote scp process: ", scpCommand)
 	if err := session.Start(scpCommand); err != nil {
 		return err
 	}
@@ -673,7 +707,7 @@ func (c *comm) scpSession(scpCommand string, f func(io.Writer, *bufio.Reader) er
 	// Call our callback that executes in the context of SCP. We ignore
 	// EOF errors if they occur because it usually means that SCP prematurely
 	// ended on the other side.
-	log.Println("Started SCP session, beginning transfers...")
+	log.Println("[DEBUG] Started SCP session, beginning transfers...")
 	if err := f(stdinW, stdoutR); err != nil && err != io.EOF {
 		return err
 	}
@@ -681,19 +715,24 @@ func (c *comm) scpSession(scpCommand string, f func(io.Writer, *bufio.Reader) er
 	// Close the stdin, which sends an EOF, and then set w to nil so that
 	// our defer func doesn't close it again since that is unsafe with
 	// the Go SSH package.
-	log.Println("SCP session complete, closing stdin pipe.")
+	log.Println("[DEBUG] SCP session complete, closing stdin pipe.")
 	stdinW.Close()
 	stdinW = nil
 
 	// Wait for the SCP connection to close, meaning it has consumed all
 	// our data and has completed. Or has errored.
-	log.Println("Waiting for SSH session to complete.")
+	log.Println("[DEBUG] Waiting for SSH session to complete.")
 	err = session.Wait()
 	if err != nil {
 		if exitErr, ok := err.(*ssh.ExitError); ok {
-			// Otherwise, we have an ExitErorr, meaning we can just read
+			// Otherwise, we have an ExitError, meaning we can just read
 			// the exit status
-			log.Printf("non-zero exit status: %d", exitErr.ExitStatus())
+			log.Printf("[DEBUG] non-zero exit status: %d", exitErr.ExitStatus())
+			stdoutB, err := ioutil.ReadAll(stdoutR)
+			if err != nil {
+				return err
+			}
+			log.Printf("[DEBUG] scp output: %s", stdoutB)
 
 			// If we exited with status 127, it means SCP isn't available.
 			// Return a more descriptive error for that.
@@ -707,7 +746,7 @@ func (c *comm) scpSession(scpCommand string, f func(io.Writer, *bufio.Reader) er
 		return err
 	}
 
-	log.Printf("scp stderr (length %d): %s", stderr.Len(), stderr.String())
+	log.Printf("[DEBUG] scp stderr (length %d): %s", stderr.Len(), stderr.String())
 	return nil
 }
 
@@ -755,7 +794,7 @@ func scpUploadFile(dst string, src io.Reader, w io.Writer, r *bufio.Reader, fi *
 	} else {
 		// Create a temporary file where we can copy the contents of the src
 		// so that we can determine the length, since SCP is length-prefixed.
-		tf, err := ioutil.TempFile("", "packer-upload")
+		tf, err := tmp.File("packer-upload")
 		if err != nil {
 			return fmt.Errorf("Error creating temporary file for upload: %s", err)
 		}
@@ -764,9 +803,12 @@ func scpUploadFile(dst string, src io.Reader, w io.Writer, r *bufio.Reader, fi *
 
 		mode = 0644
 
-		log.Println("Copying input data into temporary file so we can read the length")
+		log.Println("[DEBUG] Copying input data into temporary file so we can read the length")
 		if _, err := io.Copy(tf, src); err != nil {
-			return err
+			return fmt.Errorf("Error copying input data into local temporary "+
+				"file. Check that TEMPDIR has enough space. Please see "+
+				"https://www.packer.io/docs/other/environment-variables.html#tmpdir"+
+				"for more info. Error: %s", err)
 		}
 
 		// Sync the file so that the contents are definitely on disk, then
@@ -803,15 +845,11 @@ func scpUploadFile(dst string, src io.Reader, w io.Writer, r *bufio.Reader, fi *
 	}
 
 	fmt.Fprint(w, "\x00")
-	if err := checkSCPStatus(r); err != nil {
-		return err
-	}
-
-	return nil
+	return checkSCPStatus(r)
 }
 
 func scpUploadDirProtocol(name string, w io.Writer, r *bufio.Reader, f func() error, fi os.FileInfo) error {
-	log.Printf("SCP: starting directory upload: %s", name)
+	log.Printf("[DEBUG] SCP: starting directory upload: %s", name)
 
 	mode := fi.Mode().Perm()
 
@@ -828,11 +866,7 @@ func scpUploadDirProtocol(name string, w io.Writer, r *bufio.Reader, f func() er
 	}
 
 	fmt.Fprintln(w, "E")
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return err
 }
 
 func scpUploadDir(root string, fs []os.FileInfo, w io.Writer, r *bufio.Reader) error {
