@@ -1,17 +1,19 @@
 package vagrantcloud
 
 import (
+	"context"
 	"fmt"
-	"time"
+	"log"
 
-	"github.com/mitchellh/multistep"
-	"github.com/mitchellh/packer/packer"
+	"github.com/hashicorp/packer/common"
+	"github.com/hashicorp/packer/helper/multistep"
+	"github.com/hashicorp/packer/packer"
 )
 
 type stepUpload struct {
 }
 
-func (s *stepUpload) Run(state multistep.StateBag) multistep.StepAction {
+func (s *stepUpload) Run(_ context.Context, state multistep.StateBag) multistep.StepAction {
 	client := state.Get("client").(*VagrantCloudClient)
 	ui := state.Get("ui").(packer.Ui)
 	upload := state.Get("upload").(*Upload)
@@ -23,38 +25,31 @@ func (s *stepUpload) Run(state multistep.StateBag) multistep.StepAction {
 		"Depending on your internet connection and the size of the box,\n" +
 			"this may take some time")
 
-	var finalErr error
-	for i := 0; i < 3; i++ {
-		if i > 0 {
-			ui.Message(fmt.Sprintf("Uploading box, attempt %d", i+1))
-		}
+	err := common.Retry(10, 10, 3, func(i uint) (bool, error) {
+		ui.Message(fmt.Sprintf("Uploading box, attempt %d", i+1))
 
 		resp, err := client.Upload(artifactFilePath, url)
 		if err != nil {
-			finalErr = err
 			ui.Message(fmt.Sprintf(
 				"Error uploading box! Will retry in 10 seconds. Error: %s", err))
-			time.Sleep(10 * time.Second)
-			continue
+			return false, nil
 		}
 		if resp.StatusCode != 200 {
-			finalErr = fmt.Errorf("bad HTTP status: %d", resp.StatusCode)
+			log.Printf("bad HTTP status: %d", resp.StatusCode)
 			ui.Message(fmt.Sprintf(
 				"Error uploading box! Will retry in 10 seconds. Status: %d",
 				resp.StatusCode))
-			time.Sleep(10 * time.Second)
-			continue
+			return false, nil
 		}
+		return true, nil
+	})
 
-		finalErr = nil
-	}
-
-	if finalErr != nil {
-		state.Put("error", finalErr)
+	if err != nil {
+		state.Put("error", err)
 		return multistep.ActionHalt
 	}
 
-	ui.Message("Box succesfully uploaded")
+	ui.Message("Box successfully uploaded")
 
 	return multistep.ActionContinue
 }
